@@ -6,16 +6,18 @@
 LANG=C;export LANG
 SCRIPT_DIR=`dirname $0`
 LOG=${SCRIPT_DIR}/log/daedmon_check_`date +%Y%m%d`
+UNAME=`uname -n`
 
 ## root dir load
 . ${SCRIPT_DIR}/.root
 
-ERROR_QUE=${ROOT}/que/error/DAEMON_CHECK_`date +%Y%m%d`
+ERROR_LOG=${ROOT}/que/error/DAEMON_ERROR_${UNAME}_`date +%Y%m%d`
+
 DAEMON_CHECK=`ps -ef | grep ${ROOT}/sbin/ecron_clusterd | grep -v grep`
 
 if [ "${DAEMON_CHECK}" = "" ];then
- echo "`date` daemon don't running !!" >> ${LOG}
- echo "`date` daemon don't running !!" > ${ERROR_QUE}
+ echo "`date` daemon don't running !! ${UNAME}" >> ${LOG}
+ echo "`date` daemon don't running !!" ${UNAME} >> ${ERROR_LOG}
  ${ROOT}/sbin/ecron_clusterd &
 fi
 
@@ -24,7 +26,7 @@ sleep 2
 DAEMON_CHECK=`ps -ef | grep ${ROOT}/sbin/ecron_clusterd | grep -v grep` 
 if [ "${DAEMON_CHECK}" = "" ];then
  echo "`date` daemon can't start !!" >> ${LOG}
- echo "`date` daemon can't start !!" > ${ERROR_QUE}
+ echo "`date` daemon can't start !! ${UAME}" >> ${ERROR_LOG}
 fi
 
 exit 0
