@@ -10,7 +10,7 @@ LOG=${SCRIPT_DIR}/log/delete_jobnet_log_`date +%Y%m%d`
 ## root dir load
 . ${SCRIPT_DIR}/.root
 
-#jobnet
+#jobnetlog
 for JOBNET_LOG_DIR in `cat jobnet.list`
 do
   find ${JOBNET_LOG_DIR} -type f -mtime +30 >> ${LOG} 2>&1
@@ -21,4 +21,8 @@ done
 find ${SCRIPT_DIR}/log -type f -mtime +7 >> ${LOG} 2>&1
 find ${SCRIPT_DIR}/log -type f -mtime +7 | xargs rm -f  >> ${LOG} 2>&1
 
+#snapshot
+find ${ROOT}/snapshot -type f -mtime +30 >> ${LOG} 2>&1
+find ${ROOT}/snapshot -type f -mtime +30 | xargs rm -f  >> ${LOG} 2>&1
+
 exit 0
